@@ -4,7 +4,7 @@
 
 /* dic.h */
 
-#define VERSION "5.1"
+#define VERSION "5.3"
 
 #define MAXLEN 16 /* maximal range-width, pw-length */
 
@@ -18,7 +18,7 @@
 #define IDLE_TMO 5
 #define PDIE(x) { perror(x); exit(1); }
 
-#define SECONDS 1200 /* per run */
+#define SECONDS 1800 /* per run */
 #define MAX_DELAY 24*60 /* min (before death) */
 #define RETRY_DELAY 10 /* sec */
 #define MAX_RETRY_DELAY 600 /* delay gets longer until max reached (sec) */
@@ -29,7 +29,9 @@
 #define NICE_VAL 19
 
 /* define this if flock() does not exist like under std solaris 2.3 */
+#if !defined(__FreeBSD__) && !defined(__EMX__)
 #define USE_LOCKF
+#endif /* __FreeBSD__ */
 
 #define JOB_TIMEOUT (60*55) /* jobbers are marked with timeout after 55'*/
 
